/*
-------------------------------------------------------------------------------
-- (c) Copyright 2006 Actel Corporation
--
-- name:		CoreDAC_eval.h
-- function:	Core8051s has no timer support, so here are a few routines
--				to time events based on clock frequency
-- comments:	best viewed with tabstops set to "4"
-- history:		11/22/06 - TFB created
--
-------------------------------------------------------------------------------
*/

// --------------------------------------------------------------
// declare constants
// --------------------------------------------------------------

// --------------------------------------------------------------
// declare variables
// --------------------------------------------------------------

// --------------------------------------------------------------
// declare function prototypes
// --------------------------------------------------------------

// Get a sample
// Te decouple the DAC clock and processor clock, a simple scheme
// using one of the GPIO lines was devised to latch in the new DAC 
// value into the DAC.  Likewise, another simple scheme using a GPIO
// line to trigger a saomple was also implemented.  The combination
// of these schemes means that we have to pass the DAC value to the 
// sampling function.
uint16 get_sample(uint16 DAC);

// Get an averaged sample from channel n
uint16 get_avg_sample(uint16 DAC);

// Write a 16 bit value to the GPIO_REG
void wr_to_GPIO(uint16 v);

// Print Main Menu
void PrintMenu();

// Print the rail's mean (average) value 
void PrintMean(uint16 DAC);

// Print the current SetPoint value
void PrintSetPoint(uint16 SetPoint);

// Print current DAC value
void PrintDAC(uint16 DAC);

// Write value to DAC
void SetDAC(uint16 DAC);

// --------------------------------------------------------------
// implement functions
// --------------------------------------------------------------

// Write a 16 bit value to the GPIO_REG
void wr_to_GPIO(uint16 v) {
	XWB1 = v>>8;
	GPIO_REG = v;
}

uint16 get_sample(uint16 DAC) {
	uint16 result;
	uint16 temp;
	unsigned char temp_lo;
	unsigned char busy;
	// Trigger a sample - low to high edge on GPIO_OUT[13]
	temp = 0xDFFF | DAC;
	wr_to_GPIO(temp);
	temp = DAC|0x2000;
	wr_to_GPIO(temp);
	// Wait for the conversion to complete - GPIO_IN[13] = 1 (DATA_VALID)
	temp = GPIO_REG;
	temp_lo = XRB1;
	busy = 0x20&temp_lo;
	while (busy != 0) {
		temp = GPIO_REG;
		temp_lo = XRB1;
		busy = 0x20&temp_lo;
	}
	// Read 12 bit ADC value
	result = 0x00ff&GPIO_REG;
	result = ((XRB1&0x0f)<<8)|result;
	return result;  
   }

// Get an averaged sample from channel n
uint16 get_avg_sample(uint16 DAC) {
	uint16 result;
	uint32 acc;
	uint16 i;
	result = 0;
	acc = 0;
	for (i=0; i<1024; i++)
		acc = acc + get_sample(DAC);
	result = 0x0FFF & acc>>10;
	return result;
	}

void PrintMenu() {
	tx_char(0x0d);tx_char('\n');
	tx_char(0x0d);tx_char('\n');
	tx_str("-------   Closed Loop Trimming  Demo v1.0   -------");
	tx_str("+          =>  SetPoint Up");
	tx_str("-          =>  SetPoint Down");
	tx_str("0-F        =>  SetPoint 0x000 - 0xF00 (No DAC Load)");
	tx_str("<Shift>-1  =>  SetPoint = 0.9V");
	tx_str("<Shift>-2  =>  SetPoint = 1.1V");
	tx_str("<Shift>-3  =>  SetPoint = 1.5V");
	tx_str("<Shift>-4  =>  SetPoint = 1.8V");
	tx_str("<Shift>-5  =>  SetPoint = 2.5V");
	tx_str("<Shift>-6  =>  SetPoint = 3.3V");
	tx_str("l          =>  List Values");
	tx_str("m          =>  Print This Menu");
	tx_str(" ");
	}			

void PrintMean(uint16 DAC){
	tx_str_no_nl("Mean value:     ");
	txhex(get_avg_sample(DAC),4);
	tx_char(0x0d);tx_char('\n');
	}

void PrintValues(uint16 SetPoint, uint16 DAC){
	tx_str_no_nl("SetPoint value: ");
	txhex(SetPoint,4);
	tx_char(0x0d);tx_char('\n');
	tx_str_no_nl("DAC value:      ");
	txhex(DAC,4);
	tx_char(0x0d);tx_char('\n');
	tx_char(0x0d);tx_char('\n');
	}

void SetDAC(uint16 DAC){
	uint16 temp;
	// Toggling bit 15 from high to low will load the DAC
	temp = DAC|0x8000;
	wr_to_GPIO(temp);
	temp = DAC&0x7FFF;
	wr_to_GPIO(temp);
	}