/*******************************************************************************
 * (c) Copyright 2006 Actel Corporation
 *
 *	This file contains definitions for the values used to configure the Analog
 *	Configuration Multiplexer (ACM) in the analog block of a Fusion part.
 */
#ifndef __ANALOG_CONFIG_MUX_DEFINES_H
#define __ANALOG_CONFIG_MUX_DEFINES_H	1

/*------------------------------------------------------------------------------
 * AV inputs configuration
 */
/*
 * Input not used.
 */
#define AV_IN_DISABLED			0x00000000
/*
 * Use the input to sample a voltage without prescaling. 
 */
#define AV_IN_DIRECT_INPUT		0x00000028

/*
 * Input voltage polarity
 */
#define AV_IN_POSITIVE			0x00000000
#define AV_IN_NEGATIVE			0x00000040

/*
 * Available ranges when using the input to measure a voltage through the prescaler.
 */
#define AV_IN_RANGE_16V			0x00000080
#define AV_IN_RANGE_8V			0x00000081
#define AV_IN_RANGE_4V			0x00000082
#define AV_IN_RANGE_2V			0x00000083
#define AV_IN_RANGE_1V			0x00000084
#define AV_IN_RANGE_500mV		0x00000085
#define AV_IN_RANGE_250mV		0x00000086
#define AV_IN_RANGE_125mV		0x00000087

/*------------------------------------------------------------------------------
 * AC inputs configuration
 */
/*
 * Input not used.
 */
#define AC_IN_DISABLED			0x00000000
/* 
 * Use the input to measure a voltage without prescaling. 
 */
#define AC_IN_DIRECT_INPUT		0x00002800
/* 
 * Use this input to measure a current flowing through a resistor connected 
 * between this input and the associated AVx input.
 */
#define AC_IN_CURRENT_MONITOR	0x00001010

/*
 * Input voltage polarity
 */
#define AC_IN_POSITIVE			0x00000000
#define AC_IN_NEGATIVE			0x00004000

/*
 * Available ranges when using the input to measure a voltage through the prescaler.
 */
#define AC_IN_RANGE_16V			0x00008000
#define AC_IN_RANGE_8V			0x00008100
#define AC_IN_RANGE_4V			0x00008200
#define AC_IN_RANGE_2V			0x00008300
#define AC_IN_RANGE_1V			0x00008400
#define AC_IN_RANGE_500mV		0x00008500
#define AC_IN_RANGE_250mV		0x00008600
#define AC_IN_RANGE_125mV		0x00008700

/*------------------------------------------------------------------------------
 * AG outputs configuration
 */
#define AG_OUT_DISABLED			0x00000000

#define AG_OUT_CURRENT_SOURCE	0x00000000
#define AG_OUT_CURRENT_SINK		0x00400000

#define AG_OUT_1uA				0x00000000
#define AG_OUT_3uA				0x00040000
#define AG_OUT_10uA				0x00080000
#define AG_OUT_30uA				0x000C0000
#define AG_OUT_25mA				0x00800000

/*------------------------------------------------------------------------------
 * AT inputs configuration
 */
/*
 * Input not used.
 */
#define AT_IN_DISABLED			0x00000000
/* 
 * Use the input to measure a voltage without prescaling. 
 */
#define AT_IN_DIRECT_INPUT		0x28000000
/* 
 * Use the input to measure a temperature.
 */
#define AT_IN_TEMP_MONITOR	0x10010000

/*
 * AT input voltage polarity must always be positive.
 */
#define AT_IN_POSITIVE			0x00000000

/*
 * Available ranges when using the input to measure a voltage through the prescaler.
 */
#define AT_IN_RANGE_16V			0x80000000
#define AT_IN_RANGE_4V			0x82000000

#endif
