/*
-------------------------------------------------------------------------------
-- (c) Copyright 2006 Actel Corporation
--
-- name:		coreuartapb.h
-- function:	Support routines for controlling CoreUARTapb
-- comments:	best viewed with tabstops set to "4"
-- history:		9/24/06 - TFB created
--
-------------------------------------------------------------------------------
*/

// --------------------------------------------------------------
// declare constants
// --------------------------------------------------------------

#define RX_TIMEOUT		0xff00
#define TX_TIMEOUT		0xff00

// --------------------------------------------------------------
// declare variables
// --------------------------------------------------------------


// --------------------------------------------------------------
// declare function prototypes
// --------------------------------------------------------------

// check if a character has been received from PC - if no character rx'd,
// a value of 0xffff is returned, else the actual rx character is returned
uint16 rx_char_pc ();

// tx a character to PC - returns 1 for success, 0 for failure
uchar8 tx_char_pc (char c);

// tx a string
// (automatically sends CR/LF, so no '\n' needed)
void tx_str (const char * s);

// tx a string without a '\n'
void tx_str_no_nl (const char * s);

// simple routine to tx hex string based on value of data to PC
// (2nd arg is nibble-width of data) - note, no newline printed
void txhex (unsigned int d, uint16 w);

// simple routine to return a '0' - 'F' hex character based on value of hex
char hex2char (unsigned char h);

// --------------------------------------------------------------
// implement functions
// --------------------------------------------------------------


// check if a character has been received - if no character has been received,
// a value of 0xffff is returned, else the actual rx character is returned
uint16 rx_char () {
	uint16 ret;
	uchar8 rxrdy; // Rx char ready status signal from CoreUART
	ret			= 0;
	rxrdy		= UART2_STAT&0x02;
	if (rxrdy) {
		ret = UART2_RXDATA;
	} else {
		ret = 0xffff;
	}
	return ret;
}

// tx a character - returns 1 for success, 0 for failure
uchar8 tx_char (char c) {
	uchar8 ret;
	uchar8 txrdy; // Tx char ready status signal from CoreUART
	uint16 i;
	ret			= 0;
	i			= 0;
	txrdy		= UART2_STAT&0x01;


	while (!txrdy) {
		txrdy		= UART2_STAT&0x01;
		// timeout, in case Tx never ready
		if (i==TX_TIMEOUT) {
			break;
		} else {
			i++;
		}
	}
	if (txrdy) {
		UART2_TXDATA		= c;
		ret				= 1;

	}
	return ret;
}


// tx a string
// (automatically sends CR/LF, so no '\n' needed)
void tx_str (const char * s) {
	while(*s)
		tx_char(*s++);
	tx_char(0x0d); // send CR before LF for <new line>
	tx_char('\n'); // send LF (newline)
}

// tx a string without a '\n'
void tx_str_no_nl (const char * s) {
	while(*s)
		tx_char(*s++);
}

// simple routine to return a '0' - 'F' hex character based on value of hex
char hex2char (unsigned char h) {
	char c;
	c	= '0'; // default
	if ((h >= 0)&&(h <= 9)) {
			//c	= 0x30 + h;
			c	= '0' + h;
	}
	if ((h >= 10)&&(h <= 15)) {
			c	= 'A' + h - 10;
	}
	return (c);
}

// simple routine to tx hex string based on value of data to PC
// (2nd arg is nibble-width of data) - note, no newline printed
void txhex (unsigned int d, uint16 w) {
	uint16 i;
	for (i=0;i<w;i++)
		tx_char(hex2char((d>>(4*((w-i)-1)))&0x0f));
}
